# noinspection SpellCheckingInspection
LIB_ICONS = {
    'fa': [
        'address-book', 'address-card', 'adjust', 'alarm-clock', 'align-center', 'align-justify', 'align-left',
        'align-right', 'allergies', 'ambulance', 'american-sign-language-interpreting', 'anchor',
        'angle-double-down', 'angle-double-left', 'angle-double-right', 'angle-double-up', 'angle-down',
        'angle-left', 'angle-right', 'angle-up', 'archive', 'arrow-alt-circle-down', 'arrow-alt-circle-left',
        'arrow-alt-circle-right', 'arrow-alt-circle-up', 'arrow-alt-down', 'arrow-alt-from-bottom',
        'arrow-alt-from-left', 'arrow-alt-from-right', 'arrow-alt-from-top', 'arrow-alt-left', 'arrow-alt-right',
        'arrow-alt-square-down', 'arrow-alt-square-left', 'arrow-alt-square-right', 'arrow-alt-square-up',
        'arrow-alt-to-bottom', 'arrow-alt-to-left', 'arrow-alt-to-right', 'arrow-alt-to-top', 'arrow-alt-up',
        'arrow-circle-down', 'arrow-circle-left', 'arrow-circle-right', 'arrow-circle-up', 'arrow-down',
        'arrow-from-bottom', 'arrow-from-left', 'arrow-from-right', 'arrow-from-top', 'arrow-left', 'arrow-right',
        'arrow-square-down', 'arrow-square-left', 'arrow-square-right', 'arrow-square-up', 'arrow-to-bottom',
        'arrow-to-left', 'arrow-to-right', 'arrow-to-top', 'arrow-up', 'arrows', 'arrows-alt', 'arrows-alt-h',
        'arrows-alt-v', 'arrows-h', 'arrows-v', 'assistive-listening-systems', 'asterisk', 'at', 'audio-description',
        'backward', 'badge', 'badge-check', 'balance-scale', 'ban', 'band-aid', 'barcode', 'barcode-alt',
        'barcode-read', 'barcode-scan', 'bars', 'baseball', 'baseball-ball', 'basketball-ball', 'basketball-hoop',
        'bath', 'battery-bolt', 'battery-empty', 'battery-full', 'battery-half', 'battery-quarter', 'battery-slash',
        'battery-three-quarters', 'bed', 'beer', 'bell', 'bell-slash', 'bicycle', 'binoculars', 'birthday-cake',
        'blanket', 'blind', 'bold', 'bolt', 'bomb', 'book', 'book-heart', 'bookmark', 'bowling-ball', 'bowling-pins',
        'box', 'box-alt', 'box-check', 'box-fragile', 'box-full', 'box-heart', 'box-open', 'box-up', 'box-usd',
        'boxes', 'boxes-alt', 'boxing-glove', 'braille', 'briefcase', 'briefcase-medical', 'browser', 'bug',
        'building', 'bullhorn', 'bullseye', 'burn', 'bus', 'calculator', 'calendar', 'calendar-alt',
        'calendar-check', 'calendar-edit', 'calendar-exclamation', 'calendar-minus', 'calendar-plus',
        'calendar-times', 'camera', 'camera-alt', 'camera-retro', 'capsules', 'car', 'caret-circle-down',
        'caret-circle-left', 'caret-circle-right', 'caret-circle-up', 'caret-down', 'caret-left', 'caret-right',
        'caret-square-down', 'caret-square-left', 'caret-square-right', 'caret-square-up', 'caret-up',
        'cart-arrow-down', 'cart-plus', 'certificate', 'chart-area', 'chart-bar', 'chart-line', 'chart-pie', 'check',
        'check-circle', 'check-square', 'chess', 'chess-bishop', 'chess-bishop-alt', 'chess-board', 'chess-clock',
        'chess-clock-alt', 'chess-king', 'chess-king-alt', 'chess-knight', 'chess-knight-alt', 'chess-pawn',
        'chess-pawn-alt', 'chess-queen', 'chess-queen-alt', 'chess-rook', 'chess-rook-alt', 'chevron-circle-down',
        'chevron-circle-left', 'chevron-circle-right', 'chevron-circle-up', 'chevron-double-down',
        'chevron-double-left', 'chevron-double-right', 'chevron-double-up', 'chevron-down', 'chevron-left',
        'chevron-right', 'chevron-square-down', 'chevron-square-left', 'chevron-square-right', 'chevron-square-up',
        'chevron-up', 'child', 'circle', 'circle-notch', 'clipboard', 'clipboard-check', 'clipboard-list', 'clock',
        'clone', 'closed-captioning', 'cloud', 'cloud-download', 'cloud-download-alt', 'cloud-upload',
        'cloud-upload-alt', 'club', 'code', 'code-branch', 'code-commit', 'code-merge', 'coffee', 'cog', 'cogs',
        'columns', 'comment', 'comment-alt', 'comment-alt-check', 'comment-alt-dots', 'comment-alt-edit',
        'comment-alt-exclamation', 'comment-alt-lines', 'comment-alt-minus', 'comment-alt-plus', 'comment-alt-slash',
        'comment-alt-smile', 'comment-alt-times', 'comment-check', 'comment-dots', 'comment-edit',
        'comment-exclamation', 'comment-lines', 'comment-minus', 'comment-plus', 'comment-slash', 'comment-smile',
        'comment-times', 'comments', 'comments-alt', 'compass', 'compress', 'compress-alt', 'compress-wide',
        'container-storage', 'conveyor-belt', 'conveyor-belt-alt', 'copy', 'copyright', 'couch', 'credit-card',
        'credit-card-blank', 'credit-card-front', 'cricket', 'crop', 'crosshairs', 'cube', 'cubes', 'curling', 'cut',
        'database', 'deaf', 'desktop', 'desktop-alt', 'diagnoses', 'diamond', 'dna', 'dollar-sign', 'dolly',
        'dolly-empty', 'dolly-flatbed', 'dolly-flatbed-alt', 'dolly-flatbed-empty', 'donate', 'dot-circle', 'dove',
        'download', 'dumbbell', 'edit', 'eject', 'ellipsis-h', 'ellipsis-h-alt', 'ellipsis-v',
        'ellipsis-v-altenvelope', 'envelope-open', 'envelope-square', 'eraser', 'euro-sign', 'exchange',
        'exchange-altexclamation', 'exclamation-circle', 'exclamation-square', 'exclamation-triangle',
        'expandexpand-alt', 'expand-arrows', 'expand-arrows-alt', 'expand-wide', 'external-link',
        'external-link-altexternal-link-square', 'external-link-square-alt', 'eye', 'eye-dropper', 'eye-slash',
        'fast-backwardfast-forward', 'fax', 'female', 'field-hockey', 'fighter-jet', 'file', 'file-alt',
        'file-archive', 'file-audio', 'file-check', 'file-code', 'file-edit', 'file-excel', 'file-exclamation',
        'file-image', 'file-medical', 'file-medical-alt', 'file-minus', 'file-pdf', 'file-plus', 'file-powerpoint',
        'file-times', 'file-video', 'file-word', 'film', 'film-alt', 'filter', 'fire', 'fire-extinguisher',
        'first-aid', 'flag', 'flag-checkered', 'flask', 'folder', 'folder-open', 'font', 'football-ball',
        'football-helmet', 'forklift', 'forward', 'fragile', 'frown', 'futbol', 'gamepad', 'gavel', 'gem',
        'genderless', 'gift', 'glass-martini', 'globe', 'golf-ball', 'golf-club', 'graduation-cap', 'h-square', 'h1',
        'h2', 'h3', 'hand-heart', 'hand-holding', 'hand-holding-box', 'hand-holding-heart', 'hand-holding-seedling',
        'hand-holding-usd', 'hand-holding-water', 'hand-lizard', 'hand-paper', 'hand-peace', 'hand-point-down',
        'hand-point-left', 'hand-point-right', 'hand-point-up', 'hand-pointer', 'hand-receiving', 'hand-rock',
        'hand-scissors', 'hand-spock', 'hands', 'hands-heart', 'hands-helping', 'hands-usd', 'handshake',
        'handshake-alt', 'hashtag', 'hdd', 'heading', 'headphones', 'heart', 'heart-circle', 'heart-square',
        'heartbeat', 'hexagon', 'history', 'hockey-puck', 'hockey-sticks', 'home', 'home-heart', 'hospital',
        'hospital-alt', 'hospital-symbol', 'hourglass', 'hourglass-end', 'hourglass-half', 'hourglass-start',
        'i-cursor', 'id-badge', 'id-card', 'id-card-alt', 'image', 'images', 'inbox', 'inbox-in', 'inbox-out',
        'indent', 'industry', 'industry-alt', 'info', 'info-circle', 'info-square', 'inventory', 'italic',
        'jack-o-lantern', 'key', 'keyboard', 'lamp', 'language', 'laptop', 'leaf', 'leaf-heart', 'lemon',
        'level-down', 'level-down-alt', 'level-up', 'level-up-alt', 'life-ring', 'lightbulb', 'link', 'lira-sign',
        'list', 'list-alt', 'list-ol', 'list-ul', 'location-arrow', 'lock', 'lock-alt', 'lock-open', 'lock-open-alt',
        'long-arrow-alt-down', 'long-arrow-alt-left', 'long-arrow-alt-right', 'long-arrow-alt-up', 'long-arrow-down',
        'long-arrow-left', 'long-arrow-right', 'long-arrow-up', 'loveseat', 'low-vision', 'luchador', 'magic',
        'magnet', 'male', 'map', 'map-marker', 'map-marker-alt', 'map-pin', 'map-signs', 'mars', 'mars-double',
        'mars-stroke', 'mars-stroke-h', 'mars-stroke-v', 'medkit', 'meh', 'mercury', 'microchip', 'microphone',
        'microphone-alt', 'microphone-slash', 'minus', 'minus-circle', 'minus-hexagon', 'minus-octagon',
        'minus-square', 'mobile', 'mobile-alt', 'mobile-android', 'mobile-android-alt', 'money-bill',
        'money-bill-alt', 'moon', 'motorcycle', 'mouse-pointer', 'music', 'neuter', 'newspaper', 'notes-medical',
        'object-group', 'object-ungroup', 'octagon', 'outdent', 'paint-brush', 'pallet', 'pallet-alt', 'paper-plane',
        'paperclip', 'parachute-box', 'paragraph', 'paste', 'pause', 'pause-circle', 'paw', 'pen', 'pen-alt',
        'pen-square', 'pencil', 'pencil-alt', 'pennant', 'people-carry', 'percent', 'person-carry', 'person-dolly',
        'person-dolly-empty', 'phone', 'phone-plus', 'phone-slash', 'phone-square', 'phone-volume', 'piggy-bank',
        'pills', 'plane', 'plane-alt', 'play', 'play-circle', 'plug', 'plus', 'plus-circle', 'plus-hexagon',
        'plus-octagon', 'plus-square', 'podcast', 'poo', 'portrait', 'pound-sign', 'power-off',
        'prescription-bottle', 'prescription-bottle-alt', 'print', 'procedures', 'puzzle-piece', 'qrcode',
        'question', 'question-circle', 'question-square', 'quidditch', 'quote-left', 'quote-right', 'racquet',
        'ramp-loading', 'random', 'rectangle-landscape', 'rectangle-portrait', 'rectangle-wide', 'recycle', 'redo',
        'redo-alt', 'registered', 'repeat', 'repeat-1', 'repeat-1-alt', 'repeat-alt', 'reply', 'reply-all',
        'retweet', 'retweet-alt', 'ribbon', 'road', 'rocket', 'route', 'rss', 'rss-square', 'ruble-sign',
        'rupee-sign', 'save', 'scanner', 'scanner-keyboard', 'scanner-touchscreen', 'scrubber', 'search',
        'search-minus', 'search-plus', 'seedling', 'server', 'share', 'share-all', 'share-alt', 'share-alt-square',
        'share-square', 'shekel-sign', 'shield', 'shield-alt', 'shield-check', 'ship', 'shipping-fast',
        'shipping-timed', 'shopping-bag', 'shopping-basket', 'shopping-cart', 'shower', 'shuttlecock', 'sign',
        'sign-in', 'sign-in-alt', 'sign-language', 'sign-out', 'sign-out-alt', 'signal', 'sitemap', 'sliders-h',
        'sliders-h-square', 'sliders-v', 'sliders-v-square', 'smile', 'smile-plus', 'smoking', 'snowflake', 'sort',
        'sort-alpha-down', 'sort-alpha-up', 'sort-amount-down', 'sort-amount-up', 'sort-down', 'sort-numeric-down',
        'sort-numeric-up', 'sort-up', 'space-shuttle', 'spade', 'spinner', 'spinner-third', 'square', 'square-full',
        'star', 'star-exclamation', 'star-half', 'step-backward', 'step-forward', 'stethoscope', 'sticky-note',
        'stop', 'stop-circle', 'stopwatch', 'street-view', 'strikethrough', 'subscript', 'subway', 'suitcase', 'sun',
        'superscript', 'sync', 'sync-alt', 'syringe', 'table', 'table-tennis', 'tablet', 'tablet-alt',
        'tablet-android', 'tablet-android-alt', 'tablet-rugged', 'tablets', 'tachometer', 'tachometer-alt', 'tag',
        'tags', 'tape', 'tasks', 'taxi', 'tennis-ball', 'terminal', 'text-height', 'text-width', 'th', 'th-large',
        'th-list', 'thermometer', 'thermometer-empty', 'thermometer-full', 'thermometer-half', 'thermometer-quarter',
        'thermometer-three-quarters', 'thumbs-down', 'thumbs-up', 'thumbtack', 'ticket', 'ticket-alt', 'times',
        'times-circle', 'times-hexagon', 'times-octagon', 'times-square', 'tint', 'toggle-off', 'toggle-on',
        'trademark', 'train', 'transgender', 'transgender-alt', 'trash', 'trash-alt', 'tree', 'tree-alt', 'triangle',
        'trophy', 'trophy-alt', 'truck', 'truck-container', 'truck-couch', 'truck-loading', 'truck-moving',
        'truck-ramp', 'tty', 'tv', 'tv-retro', 'umbrella', 'underline', 'undo', 'undo-alt', 'universal-access',
        'university', 'unlink', 'unlock', 'unlock-alt', 'upload', 'usd-circle', 'usd-square', 'user', 'user-alt',
        'user-circle', 'user-md', 'user-plus', 'user-secret', 'user-times', 'users', 'utensil-fork', 'utensil-knife',
        'utensil-spoon', 'utensils', 'utensils-alt', 'venus', 'venus-double', 'venus-mars', 'vial', 'vials', 'video',
        'video-plus', 'video-slash', 'volleyball-ball', 'volume-down', 'volume-mute', 'volume-off', 'volume-up',
        'warehouse', 'warehouse-alt', 'watch', 'weight', 'wheelchair', 'whistle', 'wifi', 'window', 'window-alt',
        'window-close', 'window-maximize', 'window-minimize', 'window-restore', 'wine-glass', 'won-sign', 'wrench',
        'x-ray', 'yen-sign',
    ],
    'fab': [
        'accessible-icon', 'accusoft', 'adn', 'adversal', 'affiliatetheme', 'algolia', 'amazon', 'amazon-pay',
        'amilia', 'android', 'angellist', 'angrycreative', 'angular', 'app-store', 'app-store-ios', 'apper', 'apple',
        'apple-pay', 'asymmetrik', 'audible', 'autoprefixer', 'avianex', 'aviato', 'aws', 'bandcamp', 'behance',
        'behance-square', 'bimobject', 'bitbucket', 'bitcoin', 'bity', 'black-tie', 'blackberry', 'blogger',
        'blogger-b', 'bluetooth', 'bluetooth-b', 'btc', 'buromobelexperte', 'buysellads', 'cc-amazon-pay', 'cc-amex',
        'cc-apple-pay', 'cc-diners-club', 'cc-discover', 'cc-jcb', 'cc-mastercard', 'cc-paypal', 'cc-stripe',
        'cc-visa', 'centercode', 'chrome', 'cloudscale', 'cloudsmith', 'cloudversify', 'codepen', 'codiepie',
        'connectdevelop', 'contao', 'cpanel', 'creative-commons', 'css3', 'css3-alt', 'cuttlefish', 'd-and-d',
        'dashcube', 'delicious', 'deploydog', 'deskpro', 'deviantart', 'digg', 'digital-ocean', 'discord', 'discourse',
        'dochub', 'docker', 'draft2digital', 'dribbble', 'dribbble-square', 'dropbox', 'drupal', 'dyalog',
        'earlybirds', 'edge', 'elementor', 'ember', 'empire', 'envira', 'erlang', 'ethereum', 'etsy', 'expeditedssl',
        'facebook', 'facebook-f', 'facebook-messenger', 'facebook-square', 'firefox', 'first-order', 'firstdraft',
        'flickr', 'flipboard', 'fly', 'font-awesome', 'font-awesome-alt', 'font-awesome-flag', 'fonticons',
        'fonticons-fi', 'fort-awesome', 'fort-awesome-alt', 'forumbee', 'foursquare', 'free-code-camp', 'freebsd',
        'get-pocket', 'gg', 'gg-circle', 'git', 'git-square', 'github', 'github-alt', 'github-square', 'gitkraken',
        'gitlab', 'gitter', 'glide', 'glide-g', 'gofore', 'goodreads', 'goodreads-g', 'google', 'google-drive',
        'google-play', 'google-plus', 'google-plus-g', 'google-plus-square', 'google-wallet', 'gratipay', 'grav',
        'gripfire', 'grunt', 'gulp', 'hacker-news', 'hacker-news-square', 'hips', 'hire-a-helper', 'hooli', 'hotjar',
        'houzz', 'html5', 'hubspot', 'imdb', 'instagram', 'internet-explorer', 'ioxhost', 'itunes', 'itunes-note',
        'java', 'jenkins', 'joget', 'joomla', 'js', 'js-square', 'jsfiddle', 'keycdn', 'kickstarter', 'kickstarter-k',
        'korvue', 'laravel', 'lastfm', 'lastfm-square', 'leanpub', 'less', 'line', 'linkedin', 'linkedin-in', 'linode',
        'linux', 'lyft', 'magento', 'maxcdn', 'medapps', 'medium', 'medium-m', 'medrt', 'meetup', 'microsoft', 'mix',
        'mixcloud', 'mizuni', 'modx', 'monero', 'napster', 'nintendo-switch', 'node', 'node-js', 'npm', 'ns8',
        'nutritionix', 'odnoklassniki', 'odnoklassniki-square', 'opencart', 'openid', 'opera', 'optin-monster', 'osi',
        'page4', 'pagelines', 'palfed', 'patreon', 'paypal', 'periscope', 'phabricator', 'phoenix-framework', 'php',
        'pied-piper', 'pied-piper-alt', 'pied-piper-hat', 'pied-piper-pp', 'pinterest', 'pinterest-p',
        'pinterest-square', 'playstation', 'product-hunt', 'pushed', 'python', 'qq', 'quinscape', 'quora', 'ravelry',
        'react', 'readme', 'rebel', 'red-river', 'reddit', 'reddit-alien', 'reddit-square', 'rendact', 'renren',
        'replyd', 'resolving', 'rocketchat', 'rockrms', 'safari', 'sass', 'schlix', 'scribd', 'searchengin',
        'sellcast', 'sellsy', 'servicestack', 'shirtsinbulk', 'simplybuilt', 'sistrix', 'skyatlas', 'skype', 'slack',
        'slack-hash', 'slideshare', 'snapchat', 'snapchat-ghost', 'snapchat-square', 'soundcloud', 'speakap',
        'spotify', 'stack-exchange', 'stack-overflow', 'staylinked', 'steam', 'steam-square', 'steam-symbol',
        'sticker-mule', 'strava', 'stripe', 'stripe-s', 'studiovinari', 'stumbleupon', 'stumbleupon-circle',
        'superpowers', 'supple', 'telegram', 'telegram-plane', 'tencent-weibo', 'themeisle', 'trello', 'tripadvisor',
        'tumblr', 'tumblr-square', 'twitch', 'twitter', 'twitter-square', 'typo3', 'uber', 'uikit', 'uniregistry',
        'untappd', 'usb', 'ussunnah', 'vaadin', 'viacoin', 'viadeo', 'viadeo-square', 'viber', 'vimeo', 'vimeo-square',
        'vimeo-v', 'vine', 'vk', 'vnv', 'vuejs', 'weibo', 'weixin', 'whatsapp', 'whatsapp-square', 'whmcs',
        'wikipedia-w', 'windows', 'wordpress', 'wordpress-simple', 'wpbeginner', 'wpexplorer', 'wpforms', 'xbox',
        'xing', 'xing-square', 'y-combinator', 'yahoo', 'yandex', 'yandex-international', 'yelp', 'yoast', 'youtube',
        'youtube-square',
    ],
}
LIB_ICONS.update(far=LIB_ICONS['fa'], fal=LIB_ICONS['fa'], fas=LIB_ICONS['fa'])
LIB_ICONS.update(
    regular=LIB_ICONS['far'],
    light=LIB_ICONS['fal'],
    solid=LIB_ICONS['fas'],
    brand=LIB_ICONS['fab'],
)
COLLECTIONS = {
    **{icon: 'fab' for icon in LIB_ICONS['fab']},
    **{icon: 'fa' for icon in LIB_ICONS['fa']},
}
